@@ -52,7 +52,7 @@
 #ifdef GC_USE_SHA1
 # include "sha1.h"
 #endif
-#ifdef GC_USE_HMAC_MD5
+#if defined(GC_USE_HMAC_MD5) || defined(GC_USE_HMAC_SHA1)
 # include "hmac.h"
 #endif
 
@@ -858,9 +858,3 @@ gc_hmac_sha1 (const void *key, size_t keylen,
   return GC_OK;
 }
 #endif
-
-void
-gc_hash_hmac_setkey (gc_hash_handle handle, size_t len, const char *key)
-{
-  return;
-}
