@@ -22,6 +22,10 @@
 
 /* Parts copied from GnuTLS example programs. */
 
+#if HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
